@@ -210,6 +210,8 @@ class SoapController(controllers.Controller):
         params["_tgws"] = True
         output = method(**params)
         data = dict(baseURL=self.wscontroller._ws_baseURL,
+                    tns=self.tns,
+                    typenamespace=self.typenamespace,
                     soap_body=soap_body, output=output,
                     methodname=methodname, 
                     function_info =
